'use client';
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import clsx from 'clsx';
import { useCallback, useRef, useState, useSyncExternalStore } from 'react';
import { mergeProps, useButton, useDisclosure, useFocusRing } from 'react-aria';
import { useDisclosureState } from 'react-stately';
var globalState = {};
var listeners = new Set();
function useSyncedTabsGlobalState() {
    var subscribe = useCallback(function (callback) {
        listeners.add(callback);
        return function () { return listeners.delete(callback); };
    }, []);
    var getSnapshot = useCallback(function () { return globalState; }, []);
    var setSyncedTabs = useCallback(function (updater) {
        globalState = updater(globalState);
        listeners.forEach(function (listener) { return listener(); });
    }, []);
    var tabs = useSyncExternalStore(subscribe, getSnapshot, getSnapshot);
    return [tabs, setSyncedTabs];
}
/**
 * To optimize rendering, most of the components are server-components,
 * and the interactiveness is mainly handled by a few key components like this one.
 */
export function InteractiveSection(props) {
    var _a, _b, _c, _d;
    var id = props.id, className = props.className, _e = props.toggeable, toggeable = _e === void 0 ? false : _e, _f = props.defaultOpened, defaultOpened = _f === void 0 ? true : _f, _g = props.tabs, tabs = _g === void 0 ? [] : _g, _h = props.defaultTab, defaultTab = _h === void 0 ? (_a = tabs[0]) === null || _a === void 0 ? void 0 : _a.key : _h, header = props.header, children = props.children, overlay = props.overlay, _j = props.toggleIcon, toggleIcon = _j === void 0 ? '▶' : _j, stateKey = props.stateKey;
    var _k = useSyncedTabsGlobalState(), syncedTabs = _k[0], setSyncedTabs = _k[1];
    var tabFromState = stateKey && stateKey in syncedTabs
        ? tabs.find(function (tab) { return tab.key === syncedTabs[stateKey]; })
        : undefined;
    var _l = useState((_b = tabFromState === null || tabFromState === void 0 ? void 0 : tabFromState.key) !== null && _b !== void 0 ? _b : defaultTab), selectedTabKey = _l[0], setSelectedTab = _l[1];
    var selectedTab = (_c = tabFromState !== null && tabFromState !== void 0 ? tabFromState : tabs.find(function (tab) { return tab.key === selectedTabKey; })) !== null && _c !== void 0 ? _c : tabs[0];
    var state = useDisclosureState({
        defaultExpanded: defaultOpened,
    });
    var panelRef = useRef(null);
    var triggerRef = useRef(null);
    var _m = useDisclosure({}, state, panelRef), triggerProps = _m.buttonProps, panelProps = _m.panelProps;
    var buttonProps = useButton(triggerProps, triggerRef).buttonProps;
    var _o = useFocusRing(), isFocusVisible = _o.isFocusVisible, focusProps = _o.focusProps;
    return (<div id={id} className={clsx('openapi-section', toggeable ? 'openapi-section-toggeable' : null, className, toggeable ? "".concat(className, "-").concat(state.isExpanded ? 'opened' : 'closed') : null)}>
            {header ? (<div onClick={function () {
                if (toggeable) {
                    state.toggle();
                }
            }} className={clsx('openapi-section-header', "".concat(className, "-header"))}>
                    <div className={clsx('openapi-section-header-content', "".concat(className, "-header-content"))}>
                        {(children || (selectedTab === null || selectedTab === void 0 ? void 0 : selectedTab.body)) && toggeable ? (<button {...mergeProps(buttonProps, focusProps)} ref={triggerRef} className={clsx('openapi-section-toggle', "".concat(className, "-toggle"))} style={{
                    outline: isFocusVisible
                        ? '2px solid rgb(var(--primary-color-500) / 0.4)'
                        : 'none',
                }}>
                                {toggleIcon}
                            </button>) : null}
                        {header}
                    </div>
                    <div className={clsx('openapi-section-header-controls', "".concat(className, "-header-controls"))} onClick={function (event) {
                event.stopPropagation();
            }}>
                        {tabs.length > 1 ? (<select className={clsx('openapi-section-select', 'openapi-select', "".concat(className, "-tabs-select"))} value={(_d = selectedTab === null || selectedTab === void 0 ? void 0 : selectedTab.key) !== null && _d !== void 0 ? _d : ''} onChange={function (event) {
                    setSelectedTab(event.target.value);
                    if (stateKey) {
                        setSyncedTabs(function (state) {
                            var _a;
                            return (__assign(__assign({}, state), (_a = {}, _a[stateKey] = event.target.value, _a)));
                        });
                    }
                    state.expand();
                }}>
                                {tabs.map(function (tab) { return (<option key={tab.key} value={tab.key}>
                                        {tab.label}
                                    </option>); })}
                            </select>) : null}
                    </div>
                </div>) : null}
            {(!toggeable || state.isExpanded) && (children || (selectedTab === null || selectedTab === void 0 ? void 0 : selectedTab.body)) ? (<div ref={panelRef} {...panelProps} className={clsx('openapi-section-body', "".concat(className, "-body"))}>
                    {children}
                    {selectedTab === null || selectedTab === void 0 ? void 0 : selectedTab.body}
                </div>) : null}
            {overlay ? (<div className={clsx('openapi-section-overlay', "".concat(className, "-overlay"))}>
                    {overlay}
                </div>) : null}
        </div>);
}
