import { OpenAPISchemaProperties } from './OpenAPISchema';
import { checkIsReference, noReference, resolveDescription } from './utils';
import { OpenAPIDisclosure } from './OpenAPIDisclosure';
/**
 * Display an interactive response body.
 */
export function OpenAPIResponse(props) {
    var _a, _b, _c;
    var response = props.response, context = props.context, mediaType = props.mediaType;
    var headers = Object.entries((_a = response.headers) !== null && _a !== void 0 ? _a : {}).map(function (_a) {
        var _b;
        var name = _a[0], header = _a[1];
        return [name, (_b = noReference(header)) !== null && _b !== void 0 ? _b : {}];
    });
    var content = Object.entries((_b = mediaType.schema) !== null && _b !== void 0 ? _b : {});
    var description = resolveDescription(response);
    if (content.length === 0 && !description && headers.length === 0) {
        return null;
    }
    return (<div className="openapi-response-body">
            {headers.length > 0 ? (<OpenAPIDisclosure context={context} label={'Headers'}>
                    <OpenAPISchemaProperties properties={headers.map(function (_a) {
                var _b;
                var name = _a[0], header = _a[1];
                return ({
                    propertyName: name,
                    schema: (_b = noReference(header.schema)) !== null && _b !== void 0 ? _b : {},
                    required: header.required,
                });
            })} context={context}/>
                </OpenAPIDisclosure>) : null}
            <div className="openapi-responsebody">
                <OpenAPISchemaProperties id={"response-".concat(context.blockKey)} properties={[
            {
                schema: (_c = handleUnresolvedReference(mediaType.schema)) !== null && _c !== void 0 ? _c : {},
            },
        ]} context={context}/>
            </div>
        </div>);
}
function handleUnresolvedReference(input) {
    var isReference = checkIsReference(input);
    if (isReference || input === undefined) {
        // If we find a reference that wasn't resolved or needed to be resolved externally, do not try to render it.
        // Instead we render `any`
        return {};
    }
    return input;
}
