import { createStateKey, resolveDescription } from './utils';
import { OpenAPIResponse } from './OpenAPIResponse';
import { InteractiveSection } from './InteractiveSection';
import { OpenAPIDisclosureGroup } from './OpenAPIDisclosureGroup';
import { Markdown } from './Markdown';
/**
 * Display an interactive response body.
 */
export function OpenAPIResponses(props) {
    var responses = props.responses, context = props.context;
    return (<InteractiveSection stateKey={createStateKey('response', context.blockKey)} header="Responses" className="openapi-responses">
            <OpenAPIDisclosureGroup allowsMultipleExpanded icon={context.icons.chevronRight} groups={Object.entries(responses).map(function (_a) {
            var _b;
            var statusCode = _a[0], response = _a[1];
            var content = Object.entries((_b = response.content) !== null && _b !== void 0 ? _b : {});
            var description = resolveDescription(response);
            return {
                id: statusCode,
                label: (<div className="openapi-response-tab-content" key={"response-".concat(statusCode)}>
                                    <span className="openapi-response-statuscode">
                                        {statusCode}
                                    </span>
                                    {description ? (<Markdown source={description} className="openapi-response-description"/>) : null}
                                </div>),
                tabs: content.map(function (_a) {
                    var contentType = _a[0], mediaType = _a[1];
                    return ({
                        id: contentType,
                        label: contentType,
                        body: (<OpenAPIResponse key={"$response-".concat(statusCode, "-").concat(contentType)} response={response} mediaType={mediaType} context={context}/>),
                    });
                }),
            };
        })}/>
        </InteractiveSection>);
}
