'use client';
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { InteractiveSection } from './InteractiveSection';
import { OpenAPIRequestBody } from './OpenAPIRequestBody';
import { OpenAPIResponses } from './OpenAPIResponses';
import { OpenAPISchemaProperties } from './OpenAPISchema';
import { OpenAPISecurities } from './OpenAPISecurities';
import { noReference, resolveDescription } from './utils';
/**
 * Client component to render the spec for the request and response.
 *
 * We use a client component as rendering recursive JSON schema in the server is expensive
 * (the entire schema is rendered at once, while the client component only renders the visible part)
 */
export function OpenAPISpec(props) {
    var _a;
    var data = props.data, context = props.context;
    var operation = data.operation, securities = data.securities;
    var parameters = (_a = operation.parameters) !== null && _a !== void 0 ? _a : [];
    var parameterGroups = groupParameters(parameters);
    return (<>
            {securities.length > 0 ? (<OpenAPISecurities securities={securities} context={context}/>) : null}

            {parameterGroups.map(function (group) {
            return (<InteractiveSection key={group.key} className="openapi-parameters" header={group.label}>
                        <OpenAPISchemaProperties properties={group.parameters.map(function (parameter) {
                    var _a;
                    var description = resolveDescription(parameter);
                    return {
                        propertyName: parameter.name,
                        schema: __assign({ 
                            // Description of the parameter is defined at the parameter level
                            // we use display it if the schema doesn't override it
                            description: description, example: parameter.example, 
                            // Deprecated can be defined at the parameter level
                            deprecated: parameter.deprecated }, ((_a = noReference(parameter.schema)) !== null && _a !== void 0 ? _a : {})),
                        required: parameter.required,
                    };
                })} context={context}/>
                    </InteractiveSection>);
        })}

            {operation.requestBody ? (<OpenAPIRequestBody requestBody={noReference(operation.requestBody)} context={context}/>) : null}
            {operation.responses ? (<OpenAPIResponses responses={noReference(operation.responses)} context={context}/>) : null}
        </>);
}
function groupParameters(parameters) {
    var sorted = ['path', 'query', 'header'];
    var groups = [];
    parameters
        .filter(function (parameter) { return parameter.in; })
        .forEach(function (parameter) {
        var key = parameter.in;
        var label = getParameterGroupName(parameter.in);
        var group = groups.find(function (group) { return group.key === key; });
        if (group) {
            group.parameters.push(parameter);
        }
        else {
            groups.push({
                key: key,
                label: label,
                parameters: [parameter],
            });
        }
    });
    groups.sort(function (a, b) { return sorted.indexOf(a.key) - sorted.indexOf(b.key); });
    return groups;
}
function getParameterGroupName(paramIn) {
    switch (paramIn) {
        case 'path':
            return 'Path parameters';
        case 'query':
            return 'Query parameters';
        case 'header':
            return 'Header parameters';
        default:
            return paramIn;
    }
}
