'use client';
import { createContext, useContext, useMemo, useState } from 'react';
import { Tab, TabList, TabPanel, Tabs } from 'react-aria-components';
import { Markdown } from './Markdown';
var OpenAPITabsContext = createContext(null);
function useOpenAPITabsContext() {
    var context = useContext(OpenAPITabsContext);
    if (!context) {
        throw new Error('OpenAPITabsContext is missing');
    }
    return context;
}
/**
 * The OpenAPI Tabs wrapper component.
 */
export function OpenAPITabs(props) {
    var children = props.children, items = props.items;
    var _a = useState(function () {
        var firstItem = items[0];
        if (!firstItem) {
            throw new Error('OpenAPITabs: at least one tab is required');
        }
        return firstItem.key;
    }), selectedKey = _a[0], setSelectedKey = _a[1];
    var contextValue = { items: items, selectedKey: selectedKey, setSelectedKey: setSelectedKey };
    return (<OpenAPITabsContext.Provider value={contextValue}>
            <Tabs className="openapi-tabs" onSelectionChange={setSelectedKey} selectedKey={selectedKey}>
                {children}
            </Tabs>
        </OpenAPITabsContext.Provider>);
}
/**
 * The OpenAPI Tabs list component.
 * This component should be used as a child of the OpenAPITabs component.
 * It renders the list of tabs.
 */
export function OpenAPITabsList() {
    var items = useOpenAPITabsContext().items;
    return (<TabList className="openapi-tabs-list">
            {items.map(function (tab) { return (<Tab style={function (_a) {
                var isFocusVisible = _a.isFocusVisible;
                return ({
                    outline: isFocusVisible
                        ? '2px solid rgb(var(--primary-color-500)/0.4)'
                        : 'none',
                });
            }} className="openapi-tabs-tab" key={"Tab-".concat(tab.key)} id={tab.key}>
                    {tab.label}
                </Tab>); })}
        </TabList>);
}
/**
 * The OpenAPI Tabs panels component.
 * This component should be used as a child of the OpenAPITabs component.
 * It renders the content of the selected tab.
 */
export function OpenAPITabsPanels() {
    var _a = useOpenAPITabsContext(), selectedKey = _a.selectedKey, items = _a.items;
    var tab = useMemo(function () { return items.find(function (tab) { return tab.key === selectedKey; }); }, [items, selectedKey]);
    if (!tab) {
        return null;
    }
    return (<TabPanel key={"TabPanel-".concat(tab.key)} id={tab.key.toString()} className="openapi-tabs-panel">
            {tab.body}
            {tab.description ? (<Markdown source={tab.description} className="openapi-tabs-footer"/>) : null}
        </TabPanel>);
}
