var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { stringifyOpenAPI } from './stringifyOpenAPI';
export var codeSampleGenerators = [
    {
        id: 'curl',
        label: 'cURL',
        syntax: 'bash',
        generate: function (_a) {
            var method = _a.method, url = _a.url, headers = _a.headers, body = _a.body;
            var separator = ' \\\n';
            var lines = ['curl -L'];
            if (method.toUpperCase() !== 'GET') {
                lines.push("--request ".concat(method.toUpperCase()));
            }
            lines.push("--url '".concat(url, "'"));
            if (headers) {
                Object.entries(headers).forEach(function (_a) {
                    var key = _a[0], value = _a[1];
                    lines.push("--header '".concat(key, ": ").concat(value, "'"));
                });
            }
            if (body && Object.keys(body).length > 0) {
                lines.push("--data '".concat(stringifyOpenAPI(body), "'"));
            }
            return lines.map(function (line, index) { return (index > 0 ? indent(line, 2) : line); }).join(separator);
        },
    },
    {
        id: 'javascript',
        label: 'JavaScript',
        syntax: 'javascript',
        generate: function (_a) {
            var method = _a.method, url = _a.url, headers = _a.headers, body = _a.body;
            var code = '';
            code += "const response = await fetch('".concat(url, "', {\n    method: '").concat(method.toUpperCase(), "',\n");
            if (headers) {
                code += indent("headers: ".concat(stringifyOpenAPI(headers, null, 2), ",\n"), 4);
            }
            if (body) {
                code += indent("body: JSON.stringify(".concat(stringifyOpenAPI(body, null, 2), "),\n"), 4);
            }
            code += "});\n";
            code += "const data = await response.json();";
            return code;
        },
    },
    {
        id: 'python',
        label: 'Python',
        syntax: 'python',
        generate: function (_a) {
            var method = _a.method, url = _a.url, headers = _a.headers, body = _a.body;
            var code = 'import requests\n\n';
            code += "response = requests.".concat(method.toLowerCase(), "(\n");
            code += indent("\"".concat(url, "\",\n"), 4);
            if (headers) {
                code += indent("headers=".concat(stringifyOpenAPI(headers), ",\n"), 4);
            }
            if (body) {
                code += indent("json=".concat(stringifyOpenAPI(body), "\n"), 4);
            }
            code += ')\n';
            code += "data = response.json()";
            return code;
        },
    },
    {
        id: 'http',
        label: 'HTTP',
        syntax: 'bash',
        generate: function (_a) {
            var method = _a.method, url = _a.url, _b = _a.headers, headers = _b === void 0 ? {} : _b, body = _a.body;
            var _c = parseHostAndPath(url), host = _c.host, path = _c.path;
            if (body) {
                // if we had a body add a content length header
                var bodyContent = body ? stringifyOpenAPI(body) : '';
                // handle unicode chars with a text encoder
                var encoder = new TextEncoder();
                headers = __assign(__assign({}, headers), { 'Content-Length': encoder.encode(bodyContent).length.toString() });
            }
            if (!headers.hasOwnProperty('Accept')) {
                headers.Accept = '*/*';
            }
            var headerString = headers
                ? Object.entries(headers)
                    .map(function (_a) {
                    var key = _a[0], value = _a[1];
                    return key.toLowerCase() !== 'host' ? "".concat(key, ": ").concat(value) : "";
                })
                    .join('\n') + '\n'
                : '';
            var bodyString = body ? "\n".concat(stringifyOpenAPI(body, null, 2)) : '';
            var httpRequest = "".concat(method.toUpperCase(), " ").concat(decodeURI(path), " HTTP/1.1\nHost: ").concat(host, "\n").concat(headerString).concat(bodyString);
            return httpRequest;
        },
    },
];
function indent(code, spaces) {
    var indent = ' '.repeat(spaces);
    return code
        .split('\n')
        .map(function (line) { return (line ? indent + line : ''); })
        .join('\n');
}
export function parseHostAndPath(url) {
    try {
        var urlObj = new URL(url);
        var path = urlObj.pathname || '/';
        return { host: urlObj.host, path: path };
    }
    catch (e) {
        // If the URL was invalid do our best to parse the URL.
        // Check for the protocol part and pull it off to grab the host
        var splitted = url.split('//');
        var fullUrl = splitted[1] ? splitted[1] : url;
        // separate paths from the first element (host)
        var parts = fullUrl.split('/');
        // pull off the host (mutates)
        var host = parts.shift();
        // add a leading slash and join the paths again
        var path = '/' + parts.join('/');
        return { host: host, path: path };
    }
}
