import { toJSON, fromJSON } from 'flatted';
import { type OpenAPICustomOperationProperties, type OpenAPICustomSpecProperties, type OpenAPIV3xDocument, type Filesystem, type OpenAPIV3 } from '@gitbook/openapi-parser';
export interface OpenAPIFetcher {
    /**
     * Fetch an OpenAPI file by its URL. It should return a fully parsed OpenAPI v3 document.
     */
    fetch: (url: string) => Promise<Filesystem<OpenAPIV3xDocument>>;
}
export interface OpenAPIOperationData extends OpenAPICustomSpecProperties {
    path: string;
    method: string;
    /** Servers to be used for this operation */
    servers: OpenAPIV3.ServerObject[];
    /** Spec of the operation */
    operation: OpenAPIV3.OperationObject<OpenAPICustomOperationProperties>;
    /** Securities that should be used for this operation */
    securities: [string, OpenAPIV3.SecuritySchemeObject][];
}
export { toJSON, fromJSON };
/**
 * Resolve an OpenAPI operation in a file and compile it to a more usable format.
 */
export declare function fetchOpenAPIOperation(input: {
    url: string;
    path: string;
    method: string;
}, fetcher: OpenAPIFetcher): Promise<OpenAPIOperationData | null>;
